<?php
/*
  $Id: upcoming_products.php,v 1.1.9.1.2.3 2003/12/08 09:26:51 shota Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
*/
// max number of display item
if(Dino_Browser::is_handy()){
  $limit = MAX_DISPLAY_UPCOMING_PRODUCTS_MOBILE;
} else {
  $limit = MAX_DISPLAY_UPCOMING_PRODUCTS;
}

  $expected_query = tep_db_query("select p.products_id, pd.products_name, products_date_available as date_expected from " . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd where to_days(products_date_available) >= to_days(now()) and p.products_id = pd.products_id and pd.language_id = '" . (int)$_SESSION["languages_id"] . "' order by " . EXPECTED_PRODUCTS_FIELD . " " . EXPECTED_PRODUCTS_SORT . " limit " . $limit);
  $this->assign('num_rows', tep_db_num_rows($expected_query));
  if (tep_db_num_rows($expected_query) > 0) {
    $row = 0;
	$upc = array();
    while ($expected = tep_db_fetch_array($expected_query)) {
	  $upc[$row]['row'] = (($row+1) / 2 == floor(($row+1) / 2));
	  $upc[$row]['name'] = $expected['products_name'];
      $upc[$row]['link'] = tep_href_link(FILENAME_PRODUCT_INFO, 'products_id=' . $expected['products_id']);
      $upc[$row]['date'] = tep_date_short($expected['date_expected']);
      $row++;
    }
	$this->assign('upc', $upc);
  }
?>
